package main

import _ "embed"

//go:embed examples/demo.tape
var DemoTape []byte
